@@ -8,6 +8,8 @@ class _NumRel(measures.Measure):
     """
     __name__ = 'NumRel'
     NAME = __name__
+    PRETTY_NAME = 'Number of Relevant Documents'
+    SHORT_DESC = 'The number of relevant documents present in the qrels'
     SUPPORTED_PARAMS = {
         'rel': measures.ParamInfo(dtype=int, default=1, desc='minimum relevance score to be counted (inclusive)')
     }
