@@ -11,6 +11,8 @@ class _R(measures.Measure):
     """
     __name__ = 'R'
     NAME = __name__
+    PRETTY_NAME = 'Recall at k'
+    SHORT_DESC = 'The percentage of relevant documents retrieved in the top k results.'
     SUPPORTED_PARAMS = {
         'cutoff': measures.ParamInfo(dtype=int, required=True, desc='ranking cutoff threshold'),
         'rel': measures.ParamInfo(dtype=int, default=1, desc='minimum relevance score to be considered relevant (inclusive)')
